==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstNxTunIpv4DstCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link DstNxTunIpv4DstCaseBuilder} instances.
 *
 * @see DstNxTunIpv4DstCaseBuilder
 *
 */
public class DstNxTunIpv4DstCaseBuilder implements Builder<DstNxTunIpv4DstCase> {

    private Boolean _nxTunIpv4Dst;


    Map<Class<? extends Augmentation<DstNxTunIpv4DstCase>>, Augmentation<DstNxTunIpv4DstCase>> augmentation = Collections.emptyMap();

    public DstNxTunIpv4DstCaseBuilder() {
    }
    public DstNxTunIpv4DstCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping arg) {
        this._nxTunIpv4Dst = arg.isNxTunIpv4Dst();
    }

    public DstNxTunIpv4DstCaseBuilder(DstNxTunIpv4DstCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstNxTunIpv4DstCase>>, Augmentation<DstNxTunIpv4DstCase>> aug =((AugmentationHolder<DstNxTunIpv4DstCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxTunIpv4Dst = base.isNxTunIpv4Dst();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping) {
            this._nxTunIpv4Dst = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping)arg).isNxTunIpv4Dst();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping]");
    }

    public Boolean isNxTunIpv4Dst() {
        return _nxTunIpv4Dst;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<DstNxTunIpv4DstCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstNxTunIpv4DstCaseBuilder setNxTunIpv4Dst(final Boolean value) {
        this._nxTunIpv4Dst = value;
        return this;
    }
    
    public DstNxTunIpv4DstCaseBuilder addAugmentation(Class<? extends Augmentation<DstNxTunIpv4DstCase>> augmentationType, Augmentation<DstNxTunIpv4DstCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstNxTunIpv4DstCaseBuilder removeAugmentation(Class<? extends Augmentation<DstNxTunIpv4DstCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstNxTunIpv4DstCase build() {
        return new DstNxTunIpv4DstCaseImpl(this);
    }

    private static final class DstNxTunIpv4DstCaseImpl
        extends AbstractAugmentable<DstNxTunIpv4DstCase>
        implements DstNxTunIpv4DstCase {
    
        private final Boolean _nxTunIpv4Dst;
    
        DstNxTunIpv4DstCaseImpl(DstNxTunIpv4DstCaseBuilder base) {
            super(base.augmentation);
            this._nxTunIpv4Dst = base.isNxTunIpv4Dst();
        }
    
        @Override
        public Class<DstNxTunIpv4DstCase> getImplementedInterface() {
            return DstNxTunIpv4DstCase.class;
        }
    
        @Override
        public Boolean isNxTunIpv4Dst() {
            return _nxTunIpv4Dst;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxTunIpv4Dst);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstNxTunIpv4DstCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            DstNxTunIpv4DstCase other = (DstNxTunIpv4DstCase)obj;
            if (!Objects.equals(_nxTunIpv4Dst, other.isNxTunIpv4Dst())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstNxTunIpv4DstCaseImpl otherImpl = (DstNxTunIpv4DstCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstNxTunIpv4DstCase>>, Augmentation<DstNxTunIpv4DstCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstNxTunIpv4DstCase");
            CodeHelpers.appendValue(helper, "_nxTunIpv4Dst", _nxTunIpv4Dst);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstNxTunIpv4DstCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link DstNxTunIpv4DstCaseBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     DstNxTunIpv4DstCaseBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new DstNxTunIpv4DstCaseBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of DstNxTunIpv4DstCaseBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see DstNxTunIpv4DstCaseBuilder
 * @see Builder
 *
 */
public class DstNxTunIpv4DstCaseBuilder implements Builder<DstNxTunIpv4DstCase> {

    private Boolean _nxTunIpv4Dst;


    Map<Class<? extends Augmentation<DstNxTunIpv4DstCase>>, Augmentation<DstNxTunIpv4DstCase>> augmentation = Collections.emptyMap();

    public DstNxTunIpv4DstCaseBuilder() {
    }
    public DstNxTunIpv4DstCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping arg) {
        this._nxTunIpv4Dst = arg.isNxTunIpv4Dst();
    }

    public DstNxTunIpv4DstCaseBuilder(DstNxTunIpv4DstCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstNxTunIpv4DstCase>>, Augmentation<DstNxTunIpv4DstCase>> aug =((AugmentationHolder<DstNxTunIpv4DstCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxTunIpv4Dst = base.isNxTunIpv4Dst();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping) {
            this._nxTunIpv4Dst = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping)arg).isNxTunIpv4Dst();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxTunIpv4DstGrouping]");
    }

    public Boolean isNxTunIpv4Dst() {
        return _nxTunIpv4Dst;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<DstNxTunIpv4DstCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstNxTunIpv4DstCaseBuilder setNxTunIpv4Dst(final Boolean value) {
        this._nxTunIpv4Dst = value;
        return this;
    }
    
    public DstNxTunIpv4DstCaseBuilder addAugmentation(Class<? extends Augmentation<DstNxTunIpv4DstCase>> augmentationType, Augmentation<DstNxTunIpv4DstCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstNxTunIpv4DstCaseBuilder removeAugmentation(Class<? extends Augmentation<DstNxTunIpv4DstCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstNxTunIpv4DstCase build() {
        return new DstNxTunIpv4DstCaseImpl(this);
    }

    private static final class DstNxTunIpv4DstCaseImpl
        extends AbstractAugmentable<DstNxTunIpv4DstCase>
        implements DstNxTunIpv4DstCase {
    
        private final Boolean _nxTunIpv4Dst;
    
        DstNxTunIpv4DstCaseImpl(DstNxTunIpv4DstCaseBuilder base) {
            super(base.augmentation);
            this._nxTunIpv4Dst = base.isNxTunIpv4Dst();
        }
    
        @Override
        public Class<DstNxTunIpv4DstCase> getImplementedInterface() {
            return DstNxTunIpv4DstCase.class;
        }
    
        @Override
        public Boolean isNxTunIpv4Dst() {
            return _nxTunIpv4Dst;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxTunIpv4Dst);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstNxTunIpv4DstCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            DstNxTunIpv4DstCase other = (DstNxTunIpv4DstCase)obj;
            if (!Objects.equals(_nxTunIpv4Dst, other.isNxTunIpv4Dst())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstNxTunIpv4DstCaseImpl otherImpl = (DstNxTunIpv4DstCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstNxTunIpv4DstCase>>, Augmentation<DstNxTunIpv4DstCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstNxTunIpv4DstCase");
            CodeHelpers.appendValue(helper, "_nxTunIpv4Dst", _nxTunIpv4Dst);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
